<?php
/*
Plugin Name: Feed URL Manager
Description: Manage WordPress feed URLs: Remove unwanted links, fix Search Console errors, and redirect feed requests to original content.
Version: 1.5
Author: Networths.org
Author URI: https://networths.org
License: GPLv2 or later
License URI: https://www.gnu.org/licenses/gpl-2.0.html
*/

// Remove feed URLs if enabled in settings
function feed_url_manager_disable_feeds() {
    $disable_feeds = get_option('feed_url_manager_disable_feeds', false);
    if ($disable_feeds) {
        remove_action('wp_head', 'feed_links', 2);
        remove_action('wp_head', 'feed_links_extra', 3);
    }
}
add_action('init', 'feed_url_manager_disable_feeds');

// Redirect feed requests to the original page
function feed_url_manager_redirect_feed_requests($query) {
    if ($query->is_feed) {
        $disable_feeds = get_option('feed_url_manager_disable_feeds', false);
        if ($disable_feeds) {
            global $wp;
            $current_url = home_url(add_query_arg(array(), $wp->request));
            $original_url = preg_replace('/\/(feed|rdf|rss|rss2|atom)(\/.*|$)/', '', $current_url);
            wp_redirect($original_url, 301);
            exit;
        }
    }
}
add_action('parse_query', 'feed_url_manager_redirect_feed_requests');

// Add settings page
function feed_url_manager_add_settings_page() {
    add_options_page(
        'Feed URL Manager Settings',
        'Feed URL Manager',
        'manage_options',
        'feed-url-manager',
        'feed_url_manager_render_settings_page'
    );
}
add_action('admin_menu', 'feed_url_manager_add_settings_page');

// Render settings page
function feed_url_manager_render_settings_page() {
    $logo_url = plugin_dir_url(__FILE__) . 'assets/logo1.png'; // Path to your logo
    ?>
<div class="wrap">
    <!-- New Container Above Header -->
    <div style="background: #f9f9f9; padding: 15px; border-radius: 8px; margin-bottom: 20px; display: flex; justify-content: space-between; align-items: center;">
        <h2 style="margin: 0; font-size: 20px; color: #333; text-align: left; font-weight: normal;">Feed URL Manager Settings</h2>
        
        <!-- Donation Text and Button -->
        <div style="display: flex; align-items: center; margin-left: 15px;">
            <p style="margin: 0; font-size: 14px; color: #333; margin-right: 10px;">Your support helps us improve and maintain this plugin. If you find it useful, consider donating!</p>
            <a href="https://networths.org/donate/" target="_blank" style="background-color: #755bec; color: #fff; padding: 10px 20px; border-radius: 8px; font-size: 14px; text-decoration: none;">Donate</a>
        </div>
    </div>
</div>




<!-- Header Section -->
<div style="background: #755bec; padding: 20px; color: #fff; border-radius: 8px; display: flex; justify-content: space-between; align-items: center; position: relative;">
    <div style="display: flex; align-items: center;">
        <img src="<?php echo esc_url($logo_url); ?>" alt="Plugin Logo" style="height: 60px; margin-right: 15px;">
        <div>
            <h1 style="margin: 0; font-size: 24px; color: #fff; margin-bottom: 10px;">Feed URL Manager</h1>
            <p style="margin: 0; font-size: 14px; color: #e0e0ff; max-width: 1200px; margin-top: 5px;">
                Manage your WordPress feed URLs with ease. Remove unnecessary feed links, improve website navigation, and fix Google Search Console errors effortlessly. Enhance your user experience by ensuring feed requests redirect to original content. With this plugin, you'll have full control over feed links in your WordPress site.
            </p>
        </div>
    </div>
    <div style="text-align: right;">
        <a href="https://networths.org" target="_blank" style="color: #fff; text-decoration: none; display: flex; align-items: center;">
            <span style="font-size: 20px; margin-right: 8px;">🌐</span>
            <span>More Info</span>
        </a>
    </div>
</div>


        <form method="post" action="options.php" style="background: #fff; padding: 20px; border: 1px solid #ddd; border-radius: 8px; margin-top: 20px;">
            <?php
            settings_fields('feed_url_manager_settings_group');
            do_settings_sections('feed_url_manager_settings');
            ?>
            <table class="form-table">
                <tr valign="top">
                    <th scope="row" style="color: #35356b;">Disable Feed URLs:</th>
                    <td>
                        <input type="checkbox" name="feed_url_manager_disable_feeds" value="1" <?php checked(1, get_option('feed_url_manager_disable_feeds', false)); ?>>
                        <label for="feed_url_manager_disable_feeds" style="color: #35356b;">Remove feed URLs to avoid Google Search Console errors.</label>
                    </td>
                </tr>
            </table>
            <?php submit_button('Save Changes'); ?>
        </form>

        <div style="margin-top: 20px; text-align: center; background: #f9f9f9; padding: 15px; border: 1px solid #ddd; border-radius: 8px;">
            <p style="font-size: 16px; color: #333;">Enjoying Feed URL Manager? Give us a <strong>5-star review!</strong></p>
            <div style="font-size: 24px; color: #ffd700; margin: 10px 0;">
                ★★★★★
            </div>
            <a href="https://wordpress.org/plugins/feed-url-manager/" target="_blank" style="font-size: 14px; text-decoration: underline; color: #755bec;">Click here to leave a review!</a>
        </div>

        <div style="margin-top: 20px; text-align: center; color: #999; font-size: 14px;">
            <p>For support or assistance, please reach out to us. <a href="https://networths.org/contact-us/" target="_blank" style="color: #755bec;">Click Here</a>.</p>
        </div>
    </div>
    <?php
}

// Register settings
function feed_url_manager_register_settings() {
    register_setting('feed_url_manager_settings_group', 'feed_url_manager_disable_feeds');

    add_settings_section(
        'feed_url_manager_main_section',
        '',
        'feed_url_manager_section_callback',
        'feed_url_manager_settings'
    );
}
add_action('admin_init', 'feed_url_manager_register_settings');

// Section description
function feed_url_manager_section_callback() {
    echo '<p style="margin: 10px 0; color: #555;">Enable or disable feed URLs and fix related issues in Google Search Console.</p>';
}

// Add settings link in plugin list
function feed_url_manager_plugin_action_links($links) {
    $settings_link = '<a href="options-general.php?page=feed-url-manager">Settings</a>';
    array_unshift($links, $settings_link);
    return $links;
}
add_filter('plugin_action_links_' . plugin_basename(__FILE__), 'feed_url_manager_plugin_action_links');

// Show popup notification in bottom-right corner
function feed_url_manager_show_popup() {
    if (get_transient('feed_url_manager_show_popup')) {
        echo '<div style="position: fixed; bottom: 20px; right: 20px; background: #755bec; color: #fff; padding: 15px; border-radius: 8px; z-index: 1000;">
                <p style="margin: 0; font-size: 14px;">Feed URL Manager is active! Don’t forget to <strong>clear your cache</strong>. <a href="options-general.php?page=feed-url-manager" style="color: #fff; text-decoration: underline;">Configure Settings</a>.</p>
             </div>';
        delete_transient('feed_url_manager_show_popup');
    }
}
add_action('admin_footer', 'feed_url_manager_show_popup');

// Trigger popup on activation
function feed_url_manager_activation_hook() {
    set_transient('feed_url_manager_show_popup', true, 30); // Show for 30 seconds
}
register_activation_hook(__FILE__, 'feed_url_manager_activation_hook');
?>
